package com.tagnpin.invitereferralsapp;

import androidx.appcompat.app.AppCompatActivity;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.app.Dialog;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.invitereferrals.invitereferrals.IRInterfaces.IRTrackingCallback;
import com.invitereferrals.invitereferrals.IRInterfaces.UserDetailsCallback;
import com.invitereferrals.invitereferrals.InviteReferralsApi;

import org.json.JSONObject;

import java.util.Objects;

public class MainActivity extends AppCompatActivity {

    Dialog myDialog;

    Button referralBtn;
    Button autoLoginBtn;
    Button installBtn;
    Button registerBtn;
    Button saleBtn;

    int campaignID = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        referralBtn = findViewById(R.id.ref_btn);
        autoLoginBtn = findViewById(R.id.auto_log_btn);
        installBtn = findViewById(R.id.install_btn);
        registerBtn = findViewById(R.id.register_btn);
        saleBtn = findViewById(R.id.sale_btn);

        referralLogin();
        autoLogin();
        getCallbacks();
        installTrack();
        registerTrack();
        saleTrack();
    }

    private void referralLogin() {
        referralBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                InviteReferralsApi.getInstance(MainActivity.this).inline_btn(campaignID);
            }
        });
    }

    private void autoLogin() {
        autoLoginBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                ShowAutoLoginPopup();
            }
        });
    }

    @TargetApi(Build.VERSION_CODES.KITKAT)
    private void ShowAutoLoginPopup() {
        myDialog = new Dialog(this);
        myDialog.setContentView(R.layout.auto_login_popup);

        TextView txtClose = myDialog.findViewById(R.id.txtclose);
        txtClose.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                myDialog.dismiss();
            }
        });
        Objects.requireNonNull(myDialog.getWindow()).setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
        myDialog.show();

        Button submitBtn = myDialog.findViewById(R.id.submit);
        final EditText nameET = myDialog.findViewById(R.id.nameET);
        final EditText emailET = myDialog.findViewById(R.id.emailET);
        final EditText MobET = myDialog.findViewById(R.id.mobET);

        submitBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                String name = nameET.getText().toString();
                String email = emailET.getText().toString();
                String mobile = MobET.getText().toString();

                if(!name.isEmpty() && !email.isEmpty() && !mobile.isEmpty()) {
                    Toast.makeText(MainActivity.this,"Auto-Login Activated!!",Toast.LENGTH_SHORT).show();
                    myDialog.dismiss();
                    InviteReferralsApi.getInstance(MainActivity.this).userDetails(name,email,mobile,campaignID,null,null);
                } else {
                    Toast.makeText(MainActivity.this,"Fields cannot be empty..",Toast.LENGTH_SHORT).show();
                }
            }
        });
    }

    private void installTrack() {
        installBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                InviteReferralsApi.getInstance(MainActivity.this).tracking("install",null,0,null,null);
            }
        });
    }

    @TargetApi(Build.VERSION_CODES.KITKAT)
    private void registerTrack() {
        registerBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                myDialog = new Dialog(MainActivity.this);
                myDialog.setContentView(R.layout.tracking_popup);

                TextView txtClose = myDialog.findViewById(R.id.txtclose);
                txtClose.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        myDialog.dismiss();
                    }
                });
                Objects.requireNonNull(myDialog.getWindow()).setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
                myDialog.show();

                Button submitBtn = myDialog.findViewById(R.id.submit);
                final EditText emailET = myDialog.findViewById(R.id.emailET);

                submitBtn.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View view) {
                        String email = emailET.getText().toString();

                        if(!email.isEmpty()) {
                            myDialog.dismiss();
                            InviteReferralsApi.getInstance(MainActivity.this).tracking("register",email,0,null,null);
                        } else {
                            Toast.makeText(MainActivity.this,"Field cannot be empty..",Toast.LENGTH_SHORT).show();
                        }
                    }
                });
            }
        });
    }

    @SuppressLint("NewApi")
    private void saleTrack() {
        saleBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                myDialog = new Dialog(MainActivity.this);
                myDialog.setContentView(R.layout.tracking_popup);

                TextView txtClose = myDialog.findViewById(R.id.txtclose);
                txtClose.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        myDialog.dismiss();
                    }
                });
                Objects.requireNonNull(myDialog.getWindow()).setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
                myDialog.show();

                Button submitBtn = myDialog.findViewById(R.id.submit);
                final EditText emailET = myDialog.findViewById(R.id.emailET);

                submitBtn.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View view) {
                        String email = emailET.getText().toString();

                        if(!email.isEmpty()) {
                            myDialog.dismiss();
                            InviteReferralsApi.getInstance(MainActivity.this).tracking("sale",email,0,null,null);
                        } else {
                            Toast.makeText(MainActivity.this,"Field cannot be empty..",Toast.LENGTH_SHORT).show();
                        }
                    }
                });
            }
        });
    }

    private void getCallbacks() {
        InviteReferralsApi.getInstance(this).userDetailListener(new UserDetailsCallback() {
            @Override
            public void userDetails(JSONObject jsonObject) {
                Log.e("IR","UserDetails Response = " + jsonObject);
                InviteReferralsApi.getInstance(MainActivity.this).inline_btn(campaignID);
            }
        });

        InviteReferralsApi.getInstance(this).ir_TrackingCallbackListener(new IRTrackingCallback() {
            @Override
            public void ir_trackingCallbackForEventName(JSONObject jsonObject) {
                Log.e("IR","Tracking Response = " + jsonObject);
            }
        });
    }

    @Override
    protected void onStop() {
        super.onStop();

        if(myDialog != null && myDialog.isShowing()) {
            myDialog.dismiss();
        }
    }

    public void popupAction(View view) {
        startActivity(new Intent(MainActivity.this, PopupActivity.class));
    }
}
